summaryrefslogtreecommitdiff
path: root/implementation/service_discovery/include/ipv4_option_impl.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'implementation/service_discovery/include/ipv4_option_impl.hpp')
-rw-r--r--implementation/service_discovery/include/ipv4_option_impl.hpp78
1 files changed, 42 insertions, 36 deletions
diff --git a/implementation/service_discovery/include/ipv4_option_impl.hpp b/implementation/service_discovery/include/ipv4_option_impl.hpp
index 8ede63d..15c04b2 100644
--- a/implementation/service_discovery/include/ipv4_option_impl.hpp
+++ b/implementation/service_discovery/include/ipv4_option_impl.hpp
@@ -1,36 +1,42 @@
-// Copyright (C) 2014-2017 Bayerische Motoren Werke Aktiengesellschaft (BMW AG)
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
-#ifndef VSOMEIP_SD_IPV4_OPTION_IMPL_HPP
-#define VSOMEIP_SD_IPV4_OPTION_IMPL_HPP
-
-#include <vsomeip/primitive_types.hpp>
-
-#include "ip_option_impl.hpp"
-
-namespace vsomeip {
-namespace sd {
-
-class ipv4_option_impl: public ip_option_impl {
-public:
- ipv4_option_impl(bool _is_multicast);
- virtual ~ipv4_option_impl();
- bool operator ==(const ipv4_option_impl &_other) const;
-
- const ipv4_address_t & get_address() const;
- void set_address(const ipv4_address_t &_address);
-
- bool is_multicast() const;
- bool serialize(vsomeip::serializer *_to) const;
- bool deserialize(vsomeip::deserializer *_from);
-
-private:
- ipv4_address_t address_;
-};
-
-} // namespace sd
-} // namespace vsomeip
-
-#endif // VSOMEIP_SD_IPV4_OPTION_IMPL_HPP
+// Copyright (C) 2014-2018 Bayerische Motoren Werke Aktiengesellschaft (BMW AG)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
+
+#ifndef VSOMEIP_V3_SD_IPV4_OPTION_IMPL_HPP_
+#define VSOMEIP_V3_SD_IPV4_OPTION_IMPL_HPP_
+
+#include <boost/asio/ip/address.hpp>
+
+#include <vsomeip/primitive_types.hpp>
+
+#include "ip_option_impl.hpp"
+
+namespace vsomeip_v3 {
+namespace sd {
+
+class ipv4_option_impl: public ip_option_impl {
+public:
+ ipv4_option_impl();
+ ipv4_option_impl(const boost::asio::ip::address &_address,
+ const uint16_t _port, const bool _is_reliable);
+ virtual ~ipv4_option_impl();
+
+ bool operator ==(const option_impl &_other) const;
+
+ const ipv4_address_t & get_address() const;
+ void set_address(const ipv4_address_t &_address);
+
+ bool is_multicast() const;
+ bool serialize(vsomeip_v3::serializer *_to) const;
+ bool deserialize(vsomeip_v3::deserializer *_from);
+
+private:
+ ipv4_address_t address_;
+};
+
+} // namespace sd
+} // namespace vsomeip_v3
+
+#endif // VSOMEIP_V3_SD_IPV4_OPTION_IMPL_HPP_
+